-- Copyright 2010-2016 by Adin Hunter Baber, all rights reserved
local QuietMacrosName, QuietMacros = ...
-- lua api
local ipairs = ipairs
-- blizzard api
local DEFAULT_CHAT_FRAME = DEFAULT_CHAT_FRAME
local GetCVar = GetCVar
local InCombatLockdown = InCombatLockdown
local SetCVar = SetCVar
local UIErrorsFrame = UIErrorsFrame
-- libs
-- local name space
local CommandList = {}
local HelpList = {}
-- locals
local _isSfxOff = false
local _isSpeechOff = false
local _dumpTable = {}


SLASH_QUIETMACROS1 = "/q"
SLASH_QUIETMACROS2 = "/Q"
SlashCmdList["QUIETMACROS"] = function(commandMessage)
    if commandMessage then
        if CommandList[commandMessage] then
            CommandList[commandMessage]()
        end
    else
        CommandList.default()
    end
end


HelpList[#HelpList+1] = "    /q help -- show list of QuietMacros commands"
function CommandList.help()
    DEFAULT_CHAT_FRAME:AddMessage("Quiet Macros commands")
    for k,v in  ipairs(HelpList) do
        DEFAULT_CHAT_FRAME:AddMessage(v)
    end
end


HelpList[#HelpList+1] = "    /q c -- clear error text"
function CommandList.c()
    UIErrorsFrame:Clear()
end


HelpList[#HelpList+1] = "    /q 0 -- turn off error speech"
CommandList["0"] = function()
    SetCVar("Sound_EnableErrorSpeech", 0)
    _isSpeechOff = true
    CommandList.default = CommandList["1"]
end


HelpList[#HelpList+1] = "    /q 1 -- turn on error speech, sfx, and clear error text"
CommandList["1"] = function()
    if _isSfxOff then
        SetCVar("Sound_EnableSFX", 1)
        _isSfxOff = false
    end
    if _isSpeechOff then
        SetCVar("Sound_EnableErrorSpeech", 1)
        _isSpeechOff = false
        CommandList.default = CommandList["0"]
    end
    UIErrorsFrame:Clear()
end


HelpList[#HelpList+1] = "    /q seo -- turn sound effects off"
function CommandList.seo()
    SetCVar("Sound_EnableSFX", 0)
    _isSfxOff = true
    CommandList.default = CommandList["1"]
end


HelpList[#HelpList+1] = "    /q nsic -- no shifting in combat"
function CommandList.nsic()
    if InCombatLockdown() then
        SetCVar("autoUnshift", 0)
    end
end


HelpList[#HelpList+1] = "    /q ns -- no shifting at all"
function CommandList.ns()
    SetCVar("autoUnshift", 0)
end


HelpList[#HelpList+1] = "    /q as -- allow shifting"
function CommandList.as()
    SetCVar("autoUnshift", 1)
end


HelpList[#HelpList+1] = "    /q dump -- sends current states to chat window"
function CommandList.dump()
    DEFAULT_CHAT_FRAME:AddMessage("Sound_EnableErrorSpeech: "..GetCVar("Sound_EnableErrorSpeech"))
    DEFAULT_CHAT_FRAME:AddMessage("Sound_EnableSFX: "..GetCVar("Sound_EnableSFX"))
    DEFAULT_CHAT_FRAME:AddMessage("autoUnshift: "..GetCVar("autoUnshift"))
end


CommandList.default = CommandList["0"]

HelpList[#HelpList+1] = "    /q accept -- accept"
function CommandList.accept()
    if StackSplitOkayButton:IsVisible() then
        StackSplitOkayButton:Click()
    elseif QuestFrameAcceptButton:IsVisible() then
        QuestFrameAcceptButton:Click()
    elseif QuestFrameCompleteButton:IsVisible() then
        QuestFrameCompleteButton:Click()
    elseif QuestFrameCompleteQuestButton:IsVisible() then
        QuestFrameCompleteQuestButton:Click()
    elseif StaticPopup1Button1:IsVisible() then
        StaticPopup1Button1:Click()
    elseif GarrisonCapacitiveDisplayFrame.CreateAllWorkOrdersButton:IsVisible() then
        GarrisonCapacitiveDisplayFrame.CreateAllWorkOrdersButton:Click()
    elseif ObliterumForgeFrame and ObliterumForgeFrame.ObliterateButton:IsVisible() then
        ObliterumForgeFrame.ObliterateButton:Click()
    end
end
